@@ -131,6 +131,7 @@ static int createconnection_tcp(char *host, int port) {
 int open_net(const char *pathname, int flags, mode_t mode) {
 	char scheme[5], host[512], file[1024];
 	char username[128], password[128];
+	char outbuf[8192];
 	char *read_buf, *read_buf_s=NULL;
 	char *smallbuf, *tmpbuf;
 	int port, fd, x, ftpfd=-1, retrmode=0;
@@ -144,12 +145,12 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 					close(fd);
 					return(-1);
 				}
-				read_buf_s=read_buf=malloc(50);
-				write(fd, "GET ", 4);
-				write(fd, file, strlen(file));
-				write(fd, " HTTP/1.0\nHost: ",16);
-				write(fd, host, strlen(host));
-				write(fd, "\n", 1);
+				read_buf_s = read_buf = malloc(50);
+
+				snprintf(outbuf, sizeof(outbuf), "GET %s HTTP/1.0\nHost: %s\n", file, host);
+
+				write(fd, outbuf, strlen(outbuf));
+
 				if (strcmp(username, "")) {
 					smallbuf=malloc(strlen(password)+strlen(username)+3);
 					smallbuf[0]=0;
@@ -157,8 +158,10 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 					strcat(smallbuf,":");
 					strcat(smallbuf,password);
 					tmpbuf=mime64(smallbuf);
-					write(fd, "Authorization: Basic ", 21);
-					write(fd, tmpbuf, strlen(tmpbuf));
+
+					snprintf(outbuf, sizeof(outbuf), "Authorization: Basic %s\n", tmpbuf);
+					write(fd, outbuf, strlen(outbuf));
+
 					free(tmpbuf);
 					free(smallbuf);
 					write(fd, "\n", 1);
